---
title: 테스트 연동 결제 환불 방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제취소/환불
seo:
  title: 테스트 연동 결제 환불 방법
  description: >-
    테스트 연동을 통해 결제된 거래건의 환불 안내입니다. 당일 취소 PG사, 실결제 미지원 PG사, 자동 환불 미지원 PG/결제수단에 따른
    환불 방법을 확인해보세요.
  keywords:
    - 테스트 연동
tags:
  - 공통
  - 결제취소-환불
pgCompanies:
  - 공통
searchTags:
  - 테스트결제 환불
  - 테스트모드 결제했는데 환불
  - 테스트연동
  - 테스트연동환불
  - 테스트 출금
  - 테스트결제
  - 테스트 결제 환불
  - 테스트 환불
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="테스트용 상점정보로 결제 테스트를 했을 때 실 결제(출금)여부와 자동 환불 처리 프로세스를 안내해 드립니다.  " />

### **실 결제 후 당일 내 자동취소되는 결제대행사**

결제대행사 정책에 따라 결제 이후 30분 · 1시간마다 자동 취소되거나 자정 전(23:00\~23:50)에 자동적으로 일괄 취소됩니다.

- KG이니시스
- KG모빌리언스
- 나이스페이먼츠
- 헥토파이낸셜
- 스마트로
- 다날

### **실 결제가 되지 않고 결제완료 응답처리되는 결제대행사**

실 결제(출금)가 되지 않고 결제 마지막 단계에서 완료 응답만 내려주는 결제대행사로, 이 경우 실제 출금이 이루어지지 않기 때문에 결제실패(ex. 잔액부족, 카드해지 등)에 대한 테스트가 불가합니다.

- NHN KCP
  - (허브형으로 제공하는 카카오페이의 경우 실 결제로 진행되며, 자동 취소 대상이 아니므로 직접 취소로 진행해야 합니다.)
- 카카오페이
- 한국결제네트웍스
- 이지페이(KICC)
- 페이코
- 토스페이
- 토스페이먼츠
- 엑심베이
- 페이팔

### **실 결제가 되지만 자동 환불되지 않는 결제대행사**

실 결제된 이후 자동환불되지 않기 때문에 직접 취소까지 진행해야 합니다.

- 페이먼트월

<Callout content="**일반 결제대행사를 통한 간편결제 서비스(허브형 간편결제)는 자동으로 취소가 안되므로**
결제 이후 반드시 직접 취소까지 진행해주시기 바랍니다." title="유의사항" icon="❗" />
